@@ -516,6 +516,9 @@ class Ciphers: # tested
         if key is None:
             salt = os.urandom(32)
             key = self.generate_symmetric_key(salt)
+            key_was_none = True
+        else:
+            key_was_none = False
         try:
             assert isinstance(string_to_encrypt, bytes)
         except AssertionError:
@@ -523,7 +526,7 @@ class Ciphers: # tested
         iv = os.urandom(16)
         cipher = AES.new(key, AES.MODE_CFB, iv=iv)
         ciphered_string = cipher.encrypt(string_to_encrypt)
-        if key is None:
+        if key_was_none is True:
             return (ciphered_string, iv, key)
         else:
             return (ciphered_string, iv)
@@ -609,6 +612,9 @@ class Ciphers: # tested
         if key is None:
             salt = os.urandom(32)
             key = self.generate_symmetric_key(salt)
+            key_was_none = True
+        else:
+            key_was_none = False
         try:
             assert isinstance(string_to_encrypt, bytes)
         except AssertionError:
@@ -616,7 +622,7 @@ class Ciphers: # tested
         iv = os.urandom(8)
         cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
         ciphered_string = cipher.encrypt(string_to_encrypt)
-        if key is None:
+        if key_was_none is True:
             return (ciphered_string, iv, key)
         else:
             return (ciphered_string, iv)
@@ -760,13 +766,16 @@ class Ciphers: # tested
         """
         if key is None:
             key = self.generate_FerNet_key()
+            key_was_none = True
+        else:
+            key_was_none = False
         f = Fernet(key)
         try:
             assert isinstance(bstring, bytes)
         except AssertionError:
             bstring = bstring.encode()
         encrypted_text = f.encrypt(bstring)
-        if key is None:
+        if key_was_none is True:
             return (encrypted_text, key)
         else:
             return (encrypted_text)
